@@ -80,7 +80,6 @@ packageLog <- function(packages = "cholera", date = NULL, all.filters = FALSE,
     if (size.filter) {
       out <- sizeFilter(out, packages, cores, dev.mode = dev.mode)
     }
-
   } else {
     if (small.filter) {
       out <- smallFilter(out, multi.core = cores, dev.mode = dev.mode)
@@ -103,8 +102,16 @@ packageLog <- function(packages = "cholera", date = NULL, all.filters = FALSE,
     }, mc.cores = cores)
   }
 
-  names(out) <- packages
+  pkgs.survived <- vapply(out, function(x) x[1, "package"], character(1L))
+  pkg.not_survived <- setdiff(packages, pkgs.survived)
 
+  if (length(pkg.not_survived) > 0) {
+    message("No filtered downloads for ", paste(pkg.not_survived, 
+      collapse = ", "), ".")
+  }
+  
+  names(out) <- pkgs.survived
+  
   if (length(packages) == 1) {
     out[[1]]
   } else {
